%This function calculates the Amari separation performance.
%
% For the algorithm see:
% 
% S. Amari, A. Cichocki, and H. H. Yang, "A new learning
% algorithm for blind signal separation", in Advances
% in Neural Information Processing Systems, D. Touretzky,
% M. Mozer, and M. Hasselmo, Eds., vol. 8, pp.
% 757-763. MIT Press, Cambridge, MA, USA, 1996.
%
% Neil Gadhok, v2.1, March 1, 2006

function [API] = Amari(x)
%Amari performance index, input P = AW

[row,column] = size(x);

Am = 0;
for i=1:row,
    
    for j=1:column,
        Am = abs(x(i,j)) /  max( abs(x(:,j)) )  + Am;
    end
    Am = Am - 1;
end

for j=1:row,
    for i=1:column,
        Am = abs(x(i,j)) /  max(abs(x(i,:)) )  + Am;
    end
    Am = Am - 1;
end

API = Am/(2*row*column - row - column); %Normalize the result between 0 and 1.