% BetaD ICA caller for dataset 1.
%
% This program generates sources, mixtures, parameters and calls the BetaD program.
% This is for 2 (m = 2) sources only.
%
% Dataset 1 consists of 100 pairs of independent random numbers from the gamma
% distribution with parameter 1.5 and 3, and 2 outliers at (25,25). 
%
% Note: Must change the directories the results are saved in, or the function will fail.
%
% Neil Gadhok, v2.1, March 1, 2006.

%Intialize matlab
clc;
clear all;
close all;
%Must set the seed.


%Generate data
%Must check the frequency spectrum of the stocastic signals generated.

for index = 1:10,
    disp(' ');
    disp(['Starting iteration 'num2str(index)]);
    
    %DataSet 1
    disp('Generating dataset ....');
    n = 100;
    DataSet1 =  gamrnd(1.5,3,2,n-2); %alpha,beta,M,N
    DataSetMean = mean(DataSet1,2);
    DataSet1 = [DataSet1(1,:),25; DataSet1(2,:),25];  %Outlier #1
    DataSet1 = [DataSet1(1,:),25; DataSet1(2,:),25];  %Outlier #2
    DataSetMax = max(abs(DataSet1'));
    
    %Let's mix the data.
    disp('Mixing dataset ....');
    s = DataSet1;  %s is a row vector
    A = [1,0;0,1];
    x = A*s;       %x is our observation matrix.
    
    
    %Let's initialize the parameters
    disp('Initializing BetaD parameters ....');
    B = 0.14;
    disp(['Beta = ',num2str(B)]);
    Winit = (2*rand(2,2))-1;                        %Generates uniform distribution          
    Winit = Winit'*Winit + 2*eye(size(Winit,2));    %To ensure it is +ve definite
    Winit = [.5,1;1,.5];
    uinit = mean(x,2);
    stopping_criterion = 0.01;         
    maxiteration_BFGS = 25;                         %Question how does this effect your Amari performance???
    maxiteration_linesearch = 20;
    p_i(1:2) = 2;                                   %This tells us which p_i(z) to use for each source.
    
    %Let's call the BetaD_ICA program
    disp('Running BetaD algorithm ....');
    tic;
    [W,u,Wss] = BetaD_ICA(x,Winit,uinit,B,stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);
    timing(index) = toc;
    disp(['Completed algorithm in ', num2str(timing(index)), ' seconds.']);
    
    %Let's calculate the separation performance
    disp('Calculating separation performance ....');
    Initial = BetaD_Lbeta(x,Winit,uinit,B,p_i);
    Separation_peformance_Initial(index) = Amari(A*Winit); %FIX: INCLUDED WHITENING
    disp(['Starting separation performance is ', num2str(Separation_peformance_Initial(index))]);
    Final = BetaD_Lbeta(x,W,u,B,p_i);
    Separation_peformance_Final(index) = Amari(A*W);
    disp(['Final separation performance is ', num2str(Separation_peformance_Final(index))]);
    
end        
disp(['The mean Initial Amari separation performance is ', num2str(mean(Separation_peformance_Initial))]);
disp(['The mean Final Amari separation performance is ', num2str(mean(Separation_peformance_Final))]);

disp(['The best Final Amari separation performance is ',num2str(min(Separation_peformance_Final))]);
disp(['The worst Final Amari separation performance is ',num2str(max(Separation_peformance_Final))]);

disp(['The average execution time is ', num2str(mean(timing))]);



%Let's plot the results
figure;

plot(DataSet1(1,1:end),DataSet1(2,1:end),'k.','MarkerSize',16);
hold;
plot(DataSet1(1,100:end),DataSet1(2,100:end),'k*','MarkerSize',16); 
xmin = -10;    xmax = 30;
ymin = -10;    ymax = 30;


%Plot labels 
%title(['\beta = ',num2str(B)]);
xlabel('Observation \fontname{Times New Roman}{ \itx_1}');
ylabel('Observation \fontname{Times New Roman}{ \itx_2}');

axis([xmin xmax ymin ymax]);

BetaD_Ind_plot(A,DataSetMean,ymin,ymax,1,'-.','k');         %Dotted = The true independent directions
BetaD_Ind_plot(W^-1,u,ymin,ymax,1,'-','k');                 %Solid = The estimated independent directions

axis([xmin xmax ymin ymax]);

Experiment_name = ['e:\Thesis\Results\',date,'\DataSet1'];
status = mkdir('e:\Thesis\Results\',date);
saveas(gcf,Experiment_name,'fig');
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',5.3,'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',5.3,'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

%end plot

