% BetaD ICA caller for dataset 3.
%
% This program generates sources, mixtures, parameters and calls the BetaD program.
% This is for 2 (m = 2) sources only.
%
% Dataset 3 consists of  200 pairs of independent random numbers from the same 
% exponential power distribution, but the first 150 pairs of are centred at the origin
% and the last 50 pairs are centred at (5,5). 
%
% Note: Must change the directories the data is loaded from and results are saved in,
% or the function will fail.
%
% Neil Gadhok, v2.1, March 1, 2006.

%Intialize matlab
clc;
clear all;
close all;
%Must set the seed.


%Generate data
%Must check the frequency spectrum of the stocastic signals generated.

for index = 1:1,
    disp(' ');
    disp(['Starting iteration ', num2str(index)]);
    
    %DataSet 3
    disp('Generating dataset ....');
    n = 200;
    [DataSet3(1,1:200),Nsmpsrd,frmrd] = load_srcdat('E:\Thesis\Code\CCECE06\Fisher_Data\Unimodal_2src\epd_125_0219.dat',1,200,index);
    [DataSet3(2,1:200),Nsmpsrd,frmrd] = load_srcdat('E:\Thesis\Code\CCECE06\Fisher_Data\Unimodal_2src\epd_145_0281.dat',1,200,index);
    DataSet3 = [DataSet3(1,1:150), DataSet3(1,151:end) + 5 ; DataSet3(2,1:150), DataSet3(2,151:end) + 5 ];
    DataSetMean = mean(DataSet3(:,1:150),2);
    DataSetMax = max(abs(DataSet3'));
    
    %Let's mix the data.
    disp('Mixing dataset ....');
    s = DataSet3;  %s is a row vector
    A = [1,0;0,1];
    x = A*s;       %x is our observation matrix.
    
    
    %Let's initialize the parameters
    disp('Initializing BetaD parameters ....');
    B = 0.21;
    disp(['Beta = ',num2str(B)]);
    %Winit = (2*rand(2,2))-1;                        %Generates uniform distribution          
    %Winit = Winit'*Winit + 2*eye(size(Winit,2));    %To ensure it is +ve definite
    Winit = [.5,1;1,.5];
    uinit = mean(x,2);
    stopping_criterion = 0.01;         
    maxiteration_BFGS = 25;                         %Question how does this effect your Amari performance???
    maxiteration_linesearch = 20;
    p_i(1:2) = 1;                                   %This tells us which p_i(z) to use for each source.
    
    %Let's call the BetaD_ICA program
    disp('Running BetaD algorithm ....');
    tic;
    [W,u,Wss] = BetaD_ICA(x,Winit,uinit,B,stopping_criterion,maxiteration_BFGS,maxiteration_linesearch,p_i);
    timing(index) = toc;
    disp(['Completed algorithm in ', num2str(timing(index)), ' seconds.']);
    
    %Let's calculate the separation performance
    disp('Calculating separation performance ....');
    Initial = BetaD_Lbeta(x,Winit,uinit,B,p_i);
    Separation_peformance_Initial(index) = Amari(A*Winit); %FIX: INCLUDED WHITENING
    disp(['Starting separation performance is ', num2str(Separation_peformance_Initial(index))]);
    Final = BetaD_Lbeta(x,W,u,B,p_i);
    Separation_peformance_Final(index) = Amari(A*W);
    disp(['Final separation performance is ', num2str(Separation_peformance_Final(index))]);
    
end

%Lets displace some statistics
disp(['The mean Initial Amari separation performance is ', num2str(mean(Separation_peformance_Initial))]);
disp(['The mean Final Amari separation performance is ', num2str(mean(Separation_peformance_Final))]);

disp(['The best Final Amari separation performance is ',num2str(min(Separation_peformance_Final))]);
disp(['The worst Final Amari separation performance is ',num2str(max(Separation_peformance_Final))]);

disp(['The average execution time is ', num2str(mean(timing))]);

%Let's plot the results
figure;

plot(DataSet3(1,1:end),DataSet3(2,1:end),'k.','MarkerSize',16);
hold;
plot(DataSet3(1,151:end),DataSet3(2,151:end),'k*','MarkerSize',16); 
xmin = -2;    xmax = 8;
ymin = -2;    ymax = 8;


%Plot labels 
title(['\beta = ',num2str(B)]);
xlabel('Observation \fontname{Times New Roman}{ \itx_1}');
ylabel('Observation \fontname{Times New Roman}{ \itx_2}');

axis([xmin xmax ymin ymax]);

BetaD_Ind_plot(A,DataSetMean,ymin,ymax,1,'-.','k');         %Dotted = The true independent directions
BetaD_Ind_plot(W^-1,u,ymin,ymax,1,'-','k');                 %Solid = The estimated independent directions

axis([xmin xmax ymin ymax]);

Experiment_name = ['e:\Thesis\Results\',date,'\DataSet3'];
status = mkdir('e:\Thesis\Results\',date);
saveas(gcf,Experiment_name,'fig');
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',5.3,'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',5.3,'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

%end plot

