%This function calculates the 1st Derivative for Beta Divergence algorithm
%November 9, 2004. N. Gadhok. v1.0
%
% Jf = BetaD_Deriv(xf,Wf,uf,Bf,p_i)
%
% xf - The observation matrix
% WF - The current demixing matrix
% uf - The current mean vector
% Bf - The value of beta.
% p_i- An index telling us what parametric equations we are using.
%
% [MiEg02] M. Minami and S. Eguchi, "Robust blind source separation by
% beta divergence," Neural Computation, vol. 14, pp. 1859-1886, 2002.


function Jf = BetaD_Deriv(xf,Wf,uf,Bf,p_i)

mf = length(uf);
nf = length(xf);
Jf = zeros(mf^2+mf,1);

if Bf == 0,

    %Eq 2.4 [MiEg02]
    
        %Find y
        y = zeros(mf,nf);
        for i = 1:nf,
            y(:,i) = Wf*xf(:,i);
        end
        
        %Find h(y)
        h=zeros(mf,1,nf);
        for i = 1:nf,
             h(:,:,i) = BetaD_h_i( y(:,i) , p_i);   %Not sure if will give same result
        end
              
                       
        hy = zeros(mf,mf,nf);
        for i = 1:nf,
            hy(:,:,i) = h(:,:,i)*(y(:,i)');
        end
        
                
        hy = (1/nf)*sum(hy,3);
        W = (diag(ones(mf,1)) - hy)*((Wf^-1)');
        
        %Find u
        u = [[];[]];    %This is to exclude u from the calculation. 
    
else %This is for B!= 0
    
    %Eq.3.6 [MiEg02]
    WTf = (Wf^-1)';
    
    %Calculate pi(i=1:m)
    pif = ones(1,nf)*abs(det(Wf));
    for i = 1:mf,
        for j = 1:nf,
            pif(j) = pif(j) *  BetaD_p_i( Wf(i,:)*xf(:,j) - uf(i) , p_i(i) );
        end
    end
    
    Wdf = zeros(mf,mf,nf);
    for j = 1:nf,
         Wdf(:,:,j) = (pif(j)^Bf) * ( diag(ones(mf,1))  - ( (BetaD_h_i( Wf*xf(:,j) - uf, p_i )) * ((Wf*xf(:,j))') ) )*WTf;
    end
    Wdf = (1/nf)*sum(Wdf,3);
    

    bB = BetaD_bB(Wf,Bf,p_i(1));  %This must be modified
    
    W = Wdf - Bf*bB*WTf; 
    %end 3.6
    
    %Eq 3.7 [MiEg02]
    
    %Calculate pi(i=1:m) (p_i^B)
    pif = ones(1,nf)*abs(det(Wf));
    for i = 1:mf,
       for j = 1:nf,
            pif(j) = pif(j) *  BetaD_p_i( Wf(i,:)*xf(:,j) - uf(i) , p_i(i) );
       end
   end
   
   udf = zeros(mf,nf);
   for j = 1:nf,
        udf(:,j) = (pif(j)^Bf) * (BetaD_h_i( Wf*xf(:,j) - uf, p_i ));
   end
   u = (1/nf)*sum(udf,2);
   %end 3.7
end

Jf = -formv(W,u);  %The (-) are needed for minimization.
