%This function calculates the Hessian for Beta Divergence
%Used for BetaD
%October 6, 2004. N. Gadhok. v1.0

function Hf = BetaD_Hessian(xf,Wf,uf,Bf)


%(1) p(y) = c/cosh(y), h(y) = tanh(y),  h'(y) = sech^2(y). Thus, d/du(tanh(wx -u) = -sech(wx-u) and d/dw(tanh(wx-u)) = sech(wx-u)*x
%(2) p(y) = c*exp(-.25 * y^4), h(y) = y^3, h'(y) = 3y^2, Thus, d/du((wx-u))^3) = -3y^2, and d/dw((wx-u)^3) = (3(wx-u)^2)*(x);

%The stopping criterion is delta v < 0.1

mf = length(uf);
nf = length(xf);
c = sqrt(2)*(gamma(.25)^-1);    %This is for (2).c changes such as to normalize the distribution
d = .25;


%Create Hf
Hf = zeros(mf^2+mf,mf^2+mf);


%Calculate pi(i=1:m) (p_i^B)
    pif = ones(1,nf);
    for i = 1:mf,
       for j = 1:nf,
          %(1) pif(j) = pif(j) * ((c/cosh( Wf(i,:)*xf(:,j) - uf(i)) )^Bf);
           pif(j) = pif(j) *  ( ( c*exp(-d* (Wf(i,:)*xf(:,j) - uf(i))^4) )^Bf );
       end
    end
    
 %end calculate pif   
     

%Calculate (abs(det(Wf))^Bf)
    detW = (abs(det(Wf))^Bf);


%(1) Find delta^2(Omega_B(xf,Wf,uf))/(deltau^2). This gives an m x m matrix

    %Create a vector containing (Bh_i^2 - h_i1)
    for i = 1:mf,
        for j = 1:nf,
           %(1) tempf(i,j) = Bf*((tanh( Wf(i,:)*xf(:,j) - uf(i) ))^2) - (-sech( Wf(i,:)*xf(:,j) - uf(i) ));     %d/du(tanh(wx -u) = -sech(wx-u) 
                tempf(i,j) = Bf*((  (Wf(i,:)*xf(:,j) - uf(i))^3)^2) - ( 3*( ( Wf(i,:)*xf(:,j) - uf(i) )^2 ));  %d/du((wx-u))^3) = -3y^2, 
        end
    end
 
   tempf2 = zeros(mf,nf);
   for i = 1:nf;
     tempf2(:,i)= pif(i)*tempf(:,i);
   end
    
   Uf =  detW * (diag( (1/nf) * sum(tempf2'))); 
   Hf(end-mf+1:end,end-mf+1:end) = Uf;

   
 %(2) Find delta^2(Omega_B(xf,Wf,uf))/(deltau delta w). This gives an m x m matrix
 
 e = zeros(mf,1);
 for i = 1:mf,
     e(i) = 1;
     tempxf = zeros(mf,mf,nf);
     for j = 1:nf,
         %(1) tempxf(:,:,j) = ( Bf*((tanh( Wf(i,:)*xf(:,j) - uf(i) ))^2) - (-sech( Wf(i,:)*xf(:,j) - uf(i) )) ) * e*xf(:,j)';     %d/dw(tanh(wx-u)) = sech(wx-u)*x?
              tempxf(:,:,j) = ( Bf*((  (Wf(i,:)*xf(:,j) - uf(i))^3)^2) - ( 3*( ( Wf(i,:)*xf(:,j) - uf(i) )^2 )))* e*xf(:,j)';   %d/dw((wx-u)^3) = (3(wx-u)^2)*(x);?
     end
    
     tempxf2 = zeros(mf,mf,nf);
     for j = 1:nf,
         tempxf2(:,:,j) = pif(i)*tempxf(:,:,j);
     end
      
     tempf = (1/nf^2) * (-detW)* sum(tempxf2,3);    %Is this right???? nf^2???
     e(i) = 0;
     
     Hf(1+ mf*(i-1):mf*i,(mf)^2+1:end) = tempf;  % Upper 
     Hf((mf)^2+1:end,1+ mf*(i-1):mf*i) = tempf'; % Lower
     
 end
 
 %(3) Find delta^2(Omega_B(xf,Wf,uf))/(deltaw delta w). This gives an m x m matrix

 
 WTf = (Wf^-1)';
  
 for i = 1:mf,
     for j = 1:mf,
        
         tempf = zeros(mf,mf);
         
         if (i == j)
             tempxf = zeros(mf,mf,nf);
             for k = 1:nf,
                 %(1) tempxf(:,:,k) = 2*Bf*((WTf(j,:)')*WTf(j,:))   -   (( Bf*((tanh( Wf(j,:)*xf(:,k) - uf(j) ))^2) - (-sech( Wf(j,:)*xf(:,k) - uf(j) )) ) * xf(:,k)*(xf(:,k)'));     %d/dw(tanh(wx-u)) = sech(wx-u)*x?
                      tempxf(:,:,k) = 2*Bf*((WTf(j,:)')*WTf(j,:))   -   (( Bf*((  (Wf(i,:)*xf(:,j) - uf(i))^3)^2) - ( 3*( ( Wf(i,:)*xf(:,j) - uf(i) )^2 )) ) * xf(:,k)*(xf(:,k)'));  %d/dw((wx-u)^3) = (3(wx-u)^2)*(x);   
             end
         end

         
         %Calculate cbf
         %(1)cbf = ( Bf/(Bf + 1) ) * ( 1/( (1/nf) * sum(pif) ) ); %Note* haven't finished. Need to approx 
         cbf = ( Bf/(Bf + 1) ) * ( ((2*(d^.25)*(gamma(.25)^-1))^Bf) * ((1+Bf)^-.25) ) * ( 1/( (1/nf) * sum(pif) ) );
         
         if isinf(cbf)      %Do something here!!
             break;
         end
         
         %cbf = 0;
         
         tempf =  (1-Bf)*(1-cbf)*(WTf(i,:)')*(WTf(j,:));
         
        
         tempxf2 = zeros(mf,mf,nf);
         for l = 1:nf,
             tempxf2(:,:,l) = pif(l)*(tempf+tempxf(:,:,l));
         end
         
         tempf = (1/nf) * (-detW)* (sum(tempxf2,3));
        
                  
         Hf(1+ mf*(i-1):mf*i,1+mf*(j-1):mf*j) = tempf;
         
     end
 end

    






    

    
    
    
    
    

