%This function calculates the BetaD likelihood function. 
%
% See Eq. 3.3 in M. Mihoko and S. Eguchi, "Robust blind source
% separation by beta divergence," Neural Computation, vol. 14,
% pp. 1859-1886, 2002.
%
%Neil Gadhok, v1.0, November 5, 2004.

function Lbeta = BetaD_Lbeta(x,W,u,B,p_i)

m = length(u);
n = length(x);

%Solve r_0

pif = ones(1,n);
for i = 1:m,
    for j = 1:n,
        pif(j) = pif(j) *  BetaD_p_i( W(i,:)*x(:,j) - u(i) , p_i(i) );
    end
end
r_0 = abs(det(W)).*pif;


%Eqn 3.3
if B == 0,
    warning off; %Since div 0 occurs often here.
    L = (1/n)*sum( log(r_0) ); %Orig
    warning on;
    %     L = (1/n)*log(prod(r_0)); %Mod 1
    %     L = (1/n)*prod(r_0);      %Mod 2
else
    b_beta = BetaD_bB(W,B,p_i(1)); %1 means for p_i(1), 2 means b_beta =0. %needs to be fixed
    L = ( (1/n)*(1/B)*sum((r_0).^B) ) - b_beta  - ((1-B)/B);
end

Lbeta = -L; %Because we want to maximize L, or minimize -L