%This function plots the weight function for BetaD.
%
% See p 1866 and Fig. 9 in M. Mihoko and S. Eguchi, "Robust blind source
% separation by beta divergence," Neural Computation, vol. 14, 
% pp. 1859-1886, 2002.
%
% Neil Gadhok, v2.0, November 5, 2004.
clear all


%DataSet 1
% n = 100;
% DataSet1 =  gamrnd(1.5,3,2,n-2); %alpha,beta,M,N
% DataSetMean = mean(DataSet1,2);
% DataSet1 = [DataSet1(1,:),25; DataSet1(2,:),25]; %Outlier #1
% DataSet1 = [DataSet1(1,:),25; DataSet1(2,:),25]; %Outlier #2
% DataSetMax = max(abs(DataSet1'));

%DataSet 2
n = 200;
DataSet2 = [load_srcdat('E:\Thesis\Code\BetaD2\Fisher_Data\Unimodal_2src\epd_125_0219.dat',1,150);load_srcdat('E:\Thesis\Code\BetaD2\Fisher_Data\Unimodal_2src\epd_145_0281.dat',1,150)]; %Load Exponential Power Distribution
DataSet_BivarNorm = binorm(0,0,4,4,.8,50);
DataSetMean = mean(DataSet2,2);
DataSet2 = [DataSet2(1,:),DataSet_BivarNorm(1,:); DataSet2(2,:),DataSet_BivarNorm(2,:)];
DataSetMax = max(abs(DataSet2'));

p_i(1:2) = 1;  
s = DataSet2;  %s is a row vector
A = [1,0;0,1]; %A is the mixing matrix
x = A*s;       %x is our observation matrix.

Wf =  A;%randn(2,2);
xf = x;
uf = mean(x,2);  %Check this
nf = n;
mf = 2;

%Betas = [0.0001,0.001,0.01,0.1];
Betas = [0.04,0.12,0.20,0.28];
%Betas = [0.02,0.06,0.10,0.14];


for k =1:4
 B = Betas(k);
 r_0 = ones(1,nf);
 for i = 1:mf,
     for j = 1:nf,
         r_0(j) = r_0(j) *  BetaD_p_i( Wf(i,:)*xf(:,j) - uf(i) , p_i(i) );
     end
 end
 r_0 = abs(det(Wf))*r_0;
 weight(k,:) = exp(B*log(r_0));
 subplot(2,2,k), plot(weight(k,:)./max(weight(k,:)));
 %subplot(2,2,k), plot(weight(k,:));
 axis square;
 title(['\beta = ', num2str(B)]);
 if k == 3,
     ylabel('Normalized Weight for Each Sample');
 end
 if (k == 3) | (k == 4),
     xlabel('Sample Number');
 end

end


Experiment_name = ['e:\Thesis\Results\',date,'\weight'];
status = mkdir('e:\Thesis\Results\',date);
saveas(gcf,Experiment_name,'fig');
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 
  
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 


figure;

% %DataSet 1
% plot(DataSet1(1,1:end),DataSet1(2,1:end),'k.','MarkerSize',16);
% hold;
% plot(DataSet1(1,101:end),DataSet1(2,101:end),'k*','MarkerSize',16); 
% xmin = -10;    xmax = 30;
% ymin = -10;    ymax = 30;
% axis([xmin xmax ymin ymax]);

%DataSet 2
plot(DataSet2(1,1:end),DataSet2(2,1:end),'k.','MarkerSize',16);
hold;
plot(DataSet2(1,151:end),DataSet2(2,151:end),'k*','MarkerSize',16); 
xmin = -5;    xmax = 5;
ymin = -5;    ymax = 5;
axis([xmin xmax ymin ymax]);

ylabel('Observation \fontname{Times New Roman}\itx_1');
xlabel('Observation \fontname{Times New Roman}\itx_2'); 


Experiment_name = ['e:\Thesis\Results\',date,'\weight_data'];
%mkdir('e:\Thesis\Results\',date);
saveas(gcf,Experiment_name,'fig');
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',5.3,'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 
  
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',5.3,'height',4,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','rgb','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 