function [Thesis_boxplot_done] = BetaD_boxplot(Amari_vector, Time_vector, Name_vector, Experiment_name)
%function [Thesis_boxplot_done] = Thesis_boxplot(Amari_vector, Time_vector, Name_vector, Experiment_name)
%
%Plots experiment results with a boxplot.
%
%INPUT:
%  Amari_vector: A vector where each row contains a normalized Amari performance index from each algorithm
%  Time_vector: A vector where each row contamins a time in seconds it took to execute the experiment for each algorithm
%  Name_vector: A vector of 1 row and n columns. Each column contains the Beta of the algorithm run.
%  Amari, Time and Name_vector should have the same number of columns.
%
%OUTPUT:
%  Thesis_boxplot_done a zero if the algorithm is not done. A one if the algorithm is done.
%
%REQUIRES: exportfig.m post 2002 version. (available at www.mathworks.com)

%v2.0 Neil Gadhok, November 5, 2004


%Example: 
%   x = randn(100,5);
%   y = {'FastICA','Infomax','JADE','BetaD','Radical'};
%   Thesis_boxplot(x,x,y,'e:\Thesis\Results\output');

%BEGIN
Thesis_boxplot_done = 0;


%Check if input is correct
[M_1,N_1] = size(Amari_vector);
[M_2,N_2] = size(Time_vector);
[M_3,N_3] = size(Name_vector);


if ~((N_1 == N_2)) %& (N_1 == N_3))
    error('INPUT: Columns are not of equal size');
end

if ~(M_1 == M_2)
    error('INPUT: Rows are not of equal size');
end
%End: Check if input is correct


Mean_time = mean(Time_vector,2);
for i = 1:length(Mean_time)
    Display_time(i) =  {sprintf('%3.2f ',Mean_time(i))};
end


%Display results
figure;
boxplot(Amari_vector');
% set(gcf,'PaperPositionMode','auto')

%thisgroup = 5;       % the group I want to change
a = findall(gca,'type','line');  % get all lines in the box plot
for j=1:length(a);
    xdata = get(a(j),'xdata');   % get their x values
    %if all(abs(xdata-thisgroup)<.5)   % find ones in the desired group
    set(a(j), 'linewidth',1)
    %end
end

%Set figure attributes

h1 = gca;
set(h1,'LineWidth',1,'FontSize',10,'FontName','Arial','XTick',[1:10],'XTickLabel',Name_vector); %'FontWeight','bold'
ylabel('Normalized Amari Error');
xlabel(' ');

%End figure attributes
%End display results

%Save images

saveas(gcf,Experiment_name,'fig');

opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',7,'height',3.5,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','eps','Color','bw','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

% 'BoundsCode','mcode',
opts = struct('bounds','tight','Renderer','painters','linestylemap',[],'width',7,'height',3.5,'fontmode','fixed', 'BoundsCode','mcode','fontsize',10,'LineWidth',1,'format','png','Color','bw','Resolution',300); %Width is 6inches
setpref('exportfig','defaults',opts);
exportfig(gcf,Experiment_name); 

%End save images

Thesis_boxplot_done = 1;
%END