function [x,Nsmpsrd,frmrd] = gen_unimixdat(kurtindx,Nsmp,frm,datadir);
% Load mixed uni-modal data
%
%	LOAD_MIXDAT(NSrc)
%
%	REQUIRED ARGUMENTS
%	Nsrc		number of input sources
%	kurtindx	Nsrc element array of kurtosis indices
%			1	=  1.8011
%			2	=  1.8244
%			3	=  2.1884
%			4	=  2.8079
%			5	=  3.2082
%			6	=  4.2222
%			7	=  6.0000
%			8	= 12.2571
%			9	= 25.2000
%
%	Nsmp		number of samples
%	frm		which frame of data to get
%
%	OPTIONAL ARGUMENTS
%
%	datadir		path to data files in fillst below. Default is local
%			directory
%
%	OUTPUTS
%
%	$Id: load_mixsrc.m,v 1.2 1999/01/12 23:05:21 fisher Exp $

%*******************************************************************************
%*
%* These are the data files and their associated alpha and kurtosis values
%*
%*******************************************************************************
if (nargin == 4)
 datadir = datadir;
else
 datadir = './';
end
fillst	= {'epd_101_0180.dat',...
	   'epd_105_0182.dat',...
	   'epd_125_0219.dat',...
	   'epd_145_0281.dat',...
	   'epd_155_0321.dat',...
	   'epd_175_0422.dat',...
	   'epd_200_0600.dat',...
	   'epd_250_1226.dat',...
	   'epd_300_2520.dat'};
alpha	= [1.01,1.05,1.25,1.45,1.55,1.75,2.00,2.50,3.00];
kurtval = 9*gamma(5*alpha-4).*gamma(alpha)./(5*gamma(3*alpha-2).^2);

Nkurt	= size(fillst,2);
Nsrc	= size(kurtindx,2);	% the total number of sources
%*******************************************************************************
%*
%* Determine file size, all are assumed to be the same size
%*
%*******************************************************************************
fid	= fopen(char(strcat(datadir,fillst(1))),'r','ieee-le');
szmx	= fsize(fid)/4;
st	= fclose(fid);
%*******************************************************************************
%*
%* Determine if requested source indices are out of range.
%*
%*******************************************************************************
if (max(kurtindx) > Nkurt) | (min(kurtindx) < 1)
 disp(['ERROR - kurtindx out of range (< 1 or > ',num2str(Nkurt),')'])
 return
end
%*******************************************************************************
%*
%* kurt_unq	sorted list of unique source indices (pointers into fillst)
%* kurtindx(kurtI)	= kurt_unq
%* kurt_unq(kurtJ)	= kurtindx
%*
%*******************************************************************************
[kurt_unq,kurtI,kurtJ]	= unique(kurtindx);
Nunq		= size(kurt_unq,2);	% number of unique source indices
%*******************************************************************************
%*
%* Compute the number of each unique source index
%*
%*******************************************************************************
Msrc		= zeros(1,Nunq);	% number of each source type
					% # kurt_unq(i) = Msrc(i)
for iunq=1:Nunq,
 Msrc(iunq)	= sum(kurtindx == kurt_unq(iunq));
end
%*******************************************************************************
%*
%* Compute the number of each unique source index
%*
%*******************************************************************************
srcmax	= max(Msrc);
frm	= max([1,frm]);
if ((srcmax*Nsmp*frm) > szmx)
 disp(num2str([srcmax,Nsmp,frm,srcmax*Nsmp*frm,szmx]))
 frm	= max([floor(szmx/srcmax/Nsmp),1]);
 disp(['frm too large for block size - set to max size :',num2str(frm)])
end
%*******************************************************************************
%*
%* Get data
%*
%*******************************************************************************
x	= zeros(Nsrc,Nsmp);
for i=1:Nunq,
 filin			= char(strcat(datadir,fillst(kurt_unq(i))));
 [s,Nsmpsrd,frmrd]	= load_srcdat(filin,Msrc(i),Nsmp,frm);
 x			= x(:,1:Nsmpsrd);
 indx			= find(kurtindx == kurt_unq(i));
 x(indx,:)		= s;
end