function [s,Nsmpsrd,frmrd] = load_srcdat(filename,Nsns,Nsmp,frm);
% Load uni-modal source data
%
%	LOAD_SRCDAT(filename,Nsns,Nsmp,frm)
%
%	REQUIRED ARGUMENTS
%	filename	file from which data is to be loaded
%	Nsns		number of sensors
%	Nsmp		number of samples
%
%	OPTIONAL ARGUMENTS
%	frm		which frame of Nsns X Nsmp data to load. If
%			frm is not given, then the default value of 1 is used.
%
%	OUTPUTS
%	s		A block of Nsns X Nsmp of data read from file,
%			filename.
%	Nsmpsrd		number of Nsns vector samples read, should be
%			Nsmp.
%	frmrd		which block of Nsns X Nsmp data was read,
%			should be frm, unless frm was set too large
%			for file size.
%
%	It is assumed that the data is organized as Nsns X Nsmp X frm,
%	where frames range from 1 to frm.
%
%	$Id: load_srcdat.m,v 1.2 1999/01/12 23:05:45 fisher Exp $


fid	= fopen(filename,'r','ieee-le');
if (fid > 0)
 sz	= fsize(fid)/4;
 if (nargin == 4)
  frm	= max([1,frm]);
  if ((Nsns*Nsmp*frm) > sz)
   disp(num2str([Nsns,Nsmp,frm,Nsns*Nsmp*frm,sz]))
   frm	= max([floor(sz/Nsns/Nsmp),1]);
   disp(['frm too large for block size - set to max size :',num2str(frm)])
  end
 elseif (nargin == 3)
  frm	= 1;
 end
 skst	= fseek(fid,Nsns*Nsmp*(frm-1)*4,'bof');
 if (skst == -1)
  ferror(fid)
 else
  [s,Nsmpsrd]	= fread(fid,[Nsns,Nsmp],'float32');
  Nsmpsrd	= Nsmpsrd/Nsns;
  frmrd		= frm;
  fidst		= fclose(fid);
 end
end
